export type Jimple = any;
export type AppConfiguration = import('wootils/esm/node/appConfiguration').AppConfiguration;
export type APIClientBase = import('wootils/esm/shared/apiClient');
export type APIClientEndpoints = import('wootils/esm/shared/apiClient').APIClientEndpoints;
export type PathUtils = import('wootils/esm/node/pathUtils').PathUtils;
export type Logger = import('wootils/esm/node/logger').Logger;
export type EnvironmentUtils = import('wootils/esm/node/environmentUtils').EnvironmentUtils;
export type EventsHub = import('wootils/esm/shared/eventsHub');
export type Provider = import('wootils/esm/shared/jimpleFns').Provider;
export type Providers = import('wootils/esm/shared/jimpleFns').Providers;
/**
 * <O>
 */
export type ProviderCreator<O> = import('wootils/esm/shared/jimpleFns').ProviderCreator<O>;
export type Express = import('express').Express;
export type HTTPServer = import('http').Server;
export type SpdyServer = import('spdy').Server;
export type SpdyOptions = import('spdy').ServerOptions;
export type Server = HTTPServer | SpdyServer;
export type RequestHandler = import('express').RequestHandler;
export type ErrorRequestHandler = import('express').ErrorRequestHandler;
export type ExpressMiddleware = RequestHandler | ErrorRequestHandler;
export type ExpressRequest = import('express').Request;
export type ExpressResponse = import('express').Response;
export type ExpressNext = import('express').NextFunction;
export type ExpressRouter = import('express').Router;
export type ClassHTTPError = typeof import("./services/common/httpError")['HTTPError'];
export type ClassAppError = typeof import("./services/common/appError")['AppError'];
export type Jimpex = import('./app').Jimpex;
export type JimpexStartCallback = (appConfiguration: AppConfiguration) => any;
export type JimpexConfigurationOptions = {
    /**
     * The app default configuration.
     * Default `null`.
     */
    default: any | null;
    /**
     * The name of the app, used for the
     * configuration files. Default `'app'`.
     */
    name: string;
    /**
     * The path to the configuration files
     * directory,
     * relative to the project root
     * directory. Default `'config/'`.
     */
    path: string;
    /**
     * Whether the configurations are inside
     * a sub directory or not. If `true`, a
     * configuration path would be
     * `config/[app-name]/[file]`.
     * Default `true`.
     */
    hasFolder: boolean;
    /**
     * The name of the environment variable
     * that will be used to set the active
     * configuration.
     * Default `'CONFIG'`.
     */
    environmentVariable: string;
    /**
     * Whether or not to check for the
     * environment variable and load a
     * configuration based on its value.
     * Default `true`.
     */
    loadFromEnvironment: boolean;
    /**
     * If `true`, the app `version` will be
     * taken from the loaded configuration,
     * otherwise, when a configuration is
     * loaded, the app will copy the version
     * it has into the configuration.
     * Default `true`.
     */
    loadVersionFromConfiguration: boolean;
    /**
     * The name format the configuration
     * files have.
     * Default:
     *
     *
     * `[app-name].[configuration-name].config.js`.
     */
    filenameFormat: string;
};
export type JimpexStaticsOptions = {
    /**
     * Whether or not to include the middleware for static files.
     * Default `true`.
     */
    enabled: boolean;
    /**
     * If `true`, the path to the statics folder will be relative
     * to the project root directory, otherwise, it will be
     * relative to the directory where the app executable file is
     * located. Default `false`.
     */
    onHome: boolean;
    /**
     * The name of both the route and the folder, relative to
     * whatever you defined with the `onHome` option. Default
     * `'static'`.
     */
    route: string;
    /**
     * By default, the folder will be the same as the `route`,
     * but you can use this option to define a relative path that
     * won't affect the route. Default `''`.
     */
    folder: string;
};
export type JimpexExpressOptions = {
    /**
     * Whether or not to enable the `trust proxy`
     * option.
     * Default `true`.
     */
    trustProxy: boolean;
    /**
     * Whether or not to remove the `x-powered-by`
     * header.
     * Default `true`.
     */
    disableXPoweredBy: boolean;
    /**
     * Whether or not to add the `compression`
     * middleware.
     * Default `true`.
     */
    compression: boolean;
    /**
     * Whether or not to add the `body-parser`
     * middleware.
     * Default `true`.
     */
    bodyParser: boolean;
    /**
     * Whether or not to add the `multer` middleware.
     * Default `true`.
     */
    multer: boolean;
};
export type JimpexDefaultServicesOptions = {
    /**
     * Whether or not to register all the `common` service
     * providers.
     * Default `true`.
     */
    common: boolean;
    /**
     * Whether or not to register all the `http` service
     * providers.
     * Default `true`.
     */
    http: boolean;
    /**
     * Whether or not to register all the `utils` service
     * providers.
     * Default `true`.
     */
    utils: boolean;
};
export type JimpexOptions = {
    /**
     * The app version. To be used on the configuration. Default `'0.0.0'`.
     */
    version: string;
    /**
     * The size limit for the requests payload. Default `'15MB'`.
     */
    filesizeLimit: string;
    /**
     * Whether or not to automatically call the `boot` method after initialization.
     * Default `true`.
     */
    boot: boolean;
    /**
     * Whether or not to enable the proxy mode, so all providers, controllers and middlewares
     * will receive a proxied reference of the container, in which they can set and get
     * resources using dot notation.
     */
    proxy: boolean;
    /**
     * The options for the app configuration service.
     */
    configuration: JimpexConfigurationOptions;
    /**
     * The options for the app static `middleware`.
     */
    statics: JimpexStaticsOptions;
    /**
     * The options for the Express app.
     */
    express: JimpexExpressOptions;
    /**
     * To tell the app which services should be registered when instantiated.
     */
    defaultServices: JimpexDefaultServicesOptions;
};
/**
 * An object that when mounted on Jimpex will take care of handling a list of specific
 * routes. The method Jimpex uses to mount a controller is {@link Jimpexmount }.
 */
export type Controller = {
    /**
     * The function Jimpex calls when mounting the
     * controller.
     */
    connect: ControllerConnectFn;
    /**
     * A flag set to `true` to identify the
     * resource as a routes controller.
     */
    controller: boolean;
};
export type ControllerProviderRegisterFn = (app: Jimpex, route: string) => Controller;
/**
 * This is a special kind of controller that not only registers routes but also adds
 * resources to the container, and to avoid doing it during the mount process, it
 * registers the resources first and then returns the actuall controller.
 */
export type ControllerProvider = {
    /**
     * The function Jimpex calls when
     * registering the provider and the one
     * that has to generate the controller.
     */
    register: ControllerProviderRegisterFn;
};
/**
 * The function called by the application container in order to mount a routes controller.
 */
export type ControllerConnectFn = (app: Jimpex, route: string) => any;
/**
 * A function called in order to generate a {@link Controller }. They usually have
 * different options that will be sent to the controller creation.
 */
export type ControllerCreatorFn = () => ControllerConnectFn;
/**
 * A special kind of {@link Controller } that can be used with {@link Jimpexmount } as a
 * regular controller, or it can be called as a function with custom parameters in order
 * to obtain a "configured {@link Controller }".
 */
export type ControllerCreator<O> = (options?: Partial<O>) => Controller | ControllerProvider;
/**
 * An object that when mounted on Jimpex add an {@link ExpressMiddleware } to the app. The
 * method Jimpex uses to mount a middleware is {@link Jimpexuse }.
 */
export type Middleware = {
    /**
     * The function Jimpex calls when mounting the
     * middleware.
     */
    connect: MiddlewareConnectFn;
    /**
     * A flag set to `true` to identify the
     * resource as a middleware.
     */
    middleware: boolean;
};
/**
 * The function called by the application container in order to use a middleware.
 */
export type MiddlewareConnectFn = (app: Jimpex) => ExpressMiddleware | null;
/**
 * A function called in order to generate a {@link Middleware }. They usually have
 * different options that will be sent to the middleware creation.
 */
export type MiddlewareCreatorFn = () => MiddlewareConnectFn;
/**
 * A special kind of {@link Middleware } that can be used with {@link Jimpexuse } as a
 * regular middleware, or it can be called as a function with custom parameters in order
 * to obtain a "configured {@link Middleware }".
 */
export type MiddlewareCreator<O> = (options?: Partial<O>) => Middleware;
export type MiddlewareLike = Middleware | ExpressMiddleware;
